@@ -22,11 +22,18 @@ from octobot_tentacles_manager.api import uninstaller
 from octobot_tentacles_manager.api import creator
 from octobot_tentacles_manager.api import installer
 from octobot_tentacles_manager.api import util
+from octobot_tentacles_manager.api import uploader
 
 from octobot_tentacles_manager.api.util import (
     manage_tentacles,
 )
 
+from octobot_tentacles_manager.api.uploader import (
+    upload_file_to_nexus,
+    upload_folder_to_nexus,
+    upload_file_or_folder_to_nexus,
+)
+
 from octobot_tentacles_manager.api.configurator import (
     get_tentacles_setup_config,
     create_tentacles_setup_config_with_tentacles,
@@ -70,6 +77,7 @@ from octobot_tentacles_manager.api.uninstaller import (
 from octobot_tentacles_manager.api.creator import (
     start_tentacle_creator,
     create_tentacles_package,
+    create_all_tentacles_bundle,
 )
 from octobot_tentacles_manager.api.installer import (
     install_all_tentacles,
@@ -116,4 +124,8 @@ __all__ = [
     "install_single_tentacle",
     "repair_installation",
     "manage_tentacles",
+    "create_all_tentacles_bundle",
+    "upload_file_to_nexus",
+    "upload_folder_to_nexus",
+    "upload_file_or_folder_to_nexus",
 ]
