@@ -18,17 +18,24 @@ import octobot_tentacles_manager.constants as constants
 
 
 class Artifact:
-    def __init__(self, name):
-        self.name = name
-        self.version = None
-        self.origin_package = constants.UNKNOWN_TENTACLES_PACKAGE_LOCATION
-        self.origin_repository = constants.UNKNOWN_REPOSITORY_LOCATION
+    ARTIFACT_NAME = "artifact"
 
-    def is_valid(self):
-        return self.version is not None
+    def __init__(self, name):
+        self.name: str = name
+        self.version: str = constants.UNKNOWN_ARTIFACT_VERSION
+        self.origin_package: str = constants.UNKNOWN_TENTACLES_PACKAGE_LOCATION
+        self.origin_repository: str = constants.UNKNOWN_REPOSITORY_LOCATION
+        self.output_path: str = None
+        self.output_dir: str = None
+
+    def is_valid(self) -> bool:
+        """
+        :return: True if the artifact version is not a None or a default value
+        """
+        return self.version is not None and self.version != constants.UNKNOWN_ARTIFACT_VERSION
 
     def __str__(self):
-        str_rep = f"{self.name} artifact ["
+        str_rep = f"{self.name} {Artifact.ARTIFACT_NAME} ["
         if self.is_valid():
             return f"version: {self.version}]"
         else:
